==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/edgeorder/kotlin/inputs/PreferencesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.edgeorder.kotlin.inputs

import com.pulumi.azurenative.edgeorder.inputs.PreferencesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Preferences related to the order
 * @property encryptionPreferences Preferences related to the Encryption.
 * @property managementResourcePreferences Preferences related to the Management resource.
 * @property notificationPreferences Notification preferences.
 * @property transportPreferences Preferences related to the shipment logistics of the order.
 */
public data class PreferencesArgs(
    public val encryptionPreferences: Output<EncryptionPreferencesArgs>? = null,
    public val managementResourcePreferences: Output<ManagementResourcePreferencesArgs>? = null,
    public val notificationPreferences: Output<List<NotificationPreferenceArgs>>? = null,
    public val transportPreferences: Output<TransportPreferencesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.edgeorder.inputs.PreferencesArgs> {
    override fun toJava(): com.pulumi.azurenative.edgeorder.inputs.PreferencesArgs =
        com.pulumi.azurenative.edgeorder.inputs.PreferencesArgs.builder()
            .encryptionPreferences(
                encryptionPreferences?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .managementResourcePreferences(
                managementResourcePreferences?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            )
            .notificationPreferences(
                notificationPreferences?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .transportPreferences(
                transportPreferences?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [PreferencesArgs].
 */
@PulumiTagMarker
public class PreferencesArgsBuilder internal constructor() {
    private var encryptionPreferences: Output<EncryptionPreferencesArgs>? = null

    private var managementResourcePreferences: Output<ManagementResourcePreferencesArgs>? = null

    private var notificationPreferences: Output<List<NotificationPreferenceArgs>>? = null

    private var transportPreferences: Output<TransportPreferencesArgs>? = null

    /**
     * @param value Preferences related to the Encryption.
     */
    @JvmName("elcldpaineqiwvte")
    public suspend fun encryptionPreferences(`value`: Output<EncryptionPreferencesArgs>) {
        this.encryptionPreferences = value
    }

    /**
     * @param value Preferences related to the Management resource.
     */
    @JvmName("owmnxjhwixaxysmu")
    public suspend
    fun managementResourcePreferences(`value`: Output<ManagementResourcePreferencesArgs>) {
        this.managementResourcePreferences = value
    }

    /**
     * @param value Notification preferences.
     */
    @JvmName("cdabkvxpykgnnejo")
    public suspend fun notificationPreferences(`value`: Output<List<NotificationPreferenceArgs>>) {
        this.notificationPreferences = value
    }

    @JvmName("efrlyuvuaugmlahy")
    public suspend fun notificationPreferences(vararg values: Output<NotificationPreferenceArgs>) {
        this.notificationPreferences = Output.all(values.asList())
    }

    /**
     * @param values Notification preferences.
     */
    @JvmName("wwctlypgkfmnpmct")
    public suspend fun notificationPreferences(values: List<Output<NotificationPreferenceArgs>>) {
        this.notificationPreferences = Output.all(values)
    }

    /**
     * @param value Preferences related to the shipment logistics of the order.
     */
    @JvmName("yotifhonnrmuaylp")
    public suspend fun transportPreferences(`value`: Output<TransportPreferencesArgs>) {
        this.transportPreferences = value
    }

    /**
     * @param value Preferences related to the Encryption.
     */
    @JvmName("nvfefcicgclpkqiq")
    public suspend fun encryptionPreferences(`value`: EncryptionPreferencesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encryptionPreferences = mapped
    }

    /**
     * @param argument Preferences related to the Encryption.
     */
    @JvmName("mpomenlbytdylwjd")
    public suspend
    fun encryptionPreferences(argument: suspend EncryptionPreferencesArgsBuilder.() -> Unit) {
        val toBeMapped = EncryptionPreferencesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.encryptionPreferences = mapped
    }

    /**
     * @param value Preferences related to the Management resource.
     */
    @JvmName("ksidfywhlkaecqfg")
    public suspend fun managementResourcePreferences(`value`: ManagementResourcePreferencesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managementResourcePreferences = mapped
    }

    /**
     * @param argument Preferences related to the Management resource.
     */
    @JvmName("tdvbufxiahldctmk")
    public suspend
    fun managementResourcePreferences(argument: suspend ManagementResourcePreferencesArgsBuilder.() -> Unit) {
        val toBeMapped = ManagementResourcePreferencesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.managementResourcePreferences = mapped
    }

    /**
     * @param value Notification preferences.
     */
    @JvmName("ouxekrcyqtuteyli")
    public suspend fun notificationPreferences(`value`: List<NotificationPreferenceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notificationPreferences = mapped
    }

    /**
     * @param argument Notification preferences.
     */
    @JvmName("ubjhmwpeuifkyhns")
    public suspend
    fun notificationPreferences(argument: List<suspend NotificationPreferenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            NotificationPreferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.notificationPreferences = mapped
    }

    /**
     * @param argument Notification preferences.
     */
    @JvmName("edjemlokpddugujj")
    public suspend fun notificationPreferences(
        vararg
        argument: suspend NotificationPreferenceArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            NotificationPreferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.notificationPreferences = mapped
    }

    /**
     * @param argument Notification preferences.
     */
    @JvmName("alartlhrpbdowsch")
    public suspend
    fun notificationPreferences(argument: suspend NotificationPreferenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(NotificationPreferenceArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.notificationPreferences = mapped
    }

    /**
     * @param values Notification preferences.
     */
    @JvmName("urdjocmvuwodnpkh")
    public suspend fun notificationPreferences(vararg values: NotificationPreferenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notificationPreferences = mapped
    }

    /**
     * @param value Preferences related to the shipment logistics of the order.
     */
    @JvmName("bbvgjdilwvaghwlf")
    public suspend fun transportPreferences(`value`: TransportPreferencesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.transportPreferences = mapped
    }

    /**
     * @param argument Preferences related to the shipment logistics of the order.
     */
    @JvmName("grvepdrxfxwhalmo")
    public suspend
    fun transportPreferences(argument: suspend TransportPreferencesArgsBuilder.() -> Unit) {
        val toBeMapped = TransportPreferencesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.transportPreferences = mapped
    }

    internal fun build(): PreferencesArgs = PreferencesArgs(
        encryptionPreferences = encryptionPreferences,
        managementResourcePreferences = managementResourcePreferences,
        notificationPreferences = notificationPreferences,
        transportPreferences = transportPreferences,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/edgeorder/kotlin/inputs/PreferencesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.edgeorder.kotlin.inputs

import com.pulumi.azurenative.edgeorder.inputs.PreferencesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Preferences related to the order
 * @property encryptionPreferences Preferences related to the Encryption.
 * @property managementResourcePreferences Preferences related to the Management resource.
 * @property notificationPreferences Notification preferences.
 * @property transportPreferences Preferences related to the shipment logistics of the order.
 */
public data class PreferencesArgs(
    public val encryptionPreferences: Output<EncryptionPreferencesArgs>? = null,
    public val managementResourcePreferences: Output<ManagementResourcePreferencesArgs>? = null,
    public val notificationPreferences: Output<List<NotificationPreferenceArgs>>? = null,
    public val transportPreferences: Output<TransportPreferencesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.edgeorder.inputs.PreferencesArgs> {
    override fun toJava(): com.pulumi.azurenative.edgeorder.inputs.PreferencesArgs =
        com.pulumi.azurenative.edgeorder.inputs.PreferencesArgs.builder()
            .encryptionPreferences(
                encryptionPreferences?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .managementResourcePreferences(
                managementResourcePreferences?.applyValue({ args0 ->
                    args0.let({ args0 -> args0.toJava() })
                }),
            )
            .notificationPreferences(
                notificationPreferences?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .transportPreferences(
                transportPreferences?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [PreferencesArgs].
 */
@PulumiTagMarker
public class PreferencesArgsBuilder internal constructor() {
    private var encryptionPreferences: Output<EncryptionPreferencesArgs>? = null

    private var managementResourcePreferences: Output<ManagementResourcePreferencesArgs>? = null

    private var notificationPreferences: Output<List<NotificationPreferenceArgs>>? = null

    private var transportPreferences: Output<TransportPreferencesArgs>? = null

    /**
     * @param value Preferences related to the Encryption.
     */
    @JvmName("xbbboxfvtgxpnurr")
    public suspend fun encryptionPreferences(`value`: Output<EncryptionPreferencesArgs>) {
        this.encryptionPreferences = value
    }

    /**
     * @param value Preferences related to the Management resource.
     */
    @JvmName("ixednsdxytpeidqj")
    public suspend
    fun managementResourcePreferences(`value`: Output<ManagementResourcePreferencesArgs>) {
        this.managementResourcePreferences = value
    }

    /**
     * @param value Notification preferences.
     */
    @JvmName("jrtjfxvgxhujdgau")
    public suspend fun notificationPreferences(`value`: Output<List<NotificationPreferenceArgs>>) {
        this.notificationPreferences = value
    }

    @JvmName("pktyajiotfulmbee")
    public suspend fun notificationPreferences(vararg values: Output<NotificationPreferenceArgs>) {
        this.notificationPreferences = Output.all(values.asList())
    }

    /**
     * @param values Notification preferences.
     */
    @JvmName("hbqsocuvgicxnoen")
    public suspend fun notificationPreferences(values: List<Output<NotificationPreferenceArgs>>) {
        this.notificationPreferences = Output.all(values)
    }

    /**
     * @param value Preferences related to the shipment logistics of the order.
     */
    @JvmName("arhbovtdjnbskkqi")
    public suspend fun transportPreferences(`value`: Output<TransportPreferencesArgs>) {
        this.transportPreferences = value
    }

    /**
     * @param value Preferences related to the Encryption.
     */
    @JvmName("ahsfxiyalvphsyid")
    public suspend fun encryptionPreferences(`value`: EncryptionPreferencesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encryptionPreferences = mapped
    }

    /**
     * @param argument Preferences related to the Encryption.
     */
    @JvmName("mjtvlgwsdjsdvtfg")
    public suspend
    fun encryptionPreferences(argument: suspend EncryptionPreferencesArgsBuilder.() -> Unit) {
        val toBeMapped = EncryptionPreferencesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.encryptionPreferences = mapped
    }

    /**
     * @param value Preferences related to the Management resource.
     */
    @JvmName("cxqoqoigbtsdxpcj")
    public suspend fun managementResourcePreferences(`value`: ManagementResourcePreferencesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managementResourcePreferences = mapped
    }

    /**
     * @param argument Preferences related to the Management resource.
     */
    @JvmName("mhbukylxfrbnrspa")
    public suspend
    fun managementResourcePreferences(argument: suspend ManagementResourcePreferencesArgsBuilder.() -> Unit) {
        val toBeMapped = ManagementResourcePreferencesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.managementResourcePreferences = mapped
    }

    /**
     * @param value Notification preferences.
     */
    @JvmName("pyfdeyxdkvvnyubf")
    public suspend fun notificationPreferences(`value`: List<NotificationPreferenceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.notificationPreferences = mapped
    }

    /**
     * @param argument Notification preferences.
     */
    @JvmName("khdqdsgxejuggftw")
    public suspend
    fun notificationPreferences(argument: List<suspend NotificationPreferenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            NotificationPreferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.notificationPreferences = mapped
    }

    /**
     * @param argument Notification preferences.
     */
    @JvmName("ncmleqbretljrtic")
    public suspend fun notificationPreferences(
        vararg
        argument: suspend NotificationPreferenceArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            NotificationPreferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.notificationPreferences = mapped
    }

    /**
     * @param argument Notification preferences.
     */
    @JvmName("mmpsqhruoncenocn")
    public suspend
    fun notificationPreferences(argument: suspend NotificationPreferenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(NotificationPreferenceArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.notificationPreferences = mapped
    }

    /**
     * @param values Notification preferences.
     */
    @JvmName("cjovobrmntbhwqhq")
    public suspend fun notificationPreferences(vararg values: NotificationPreferenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.notificationPreferences = mapped
    }

    /**
     * @param value Preferences related to the shipment logistics of the order.
     */
    @JvmName("roqgqtmlrdasjyyj")
    public suspend fun transportPreferences(`value`: TransportPreferencesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.transportPreferences = mapped
    }

    /**
     * @param argument Preferences related to the shipment logistics of the order.
     */
    @JvmName("pffhnglxaihnhhlm")
    public suspend
    fun transportPreferences(argument: suspend TransportPreferencesArgsBuilder.() -> Unit) {
        val toBeMapped = TransportPreferencesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.transportPreferences = mapped
    }

    internal fun build(): PreferencesArgs = PreferencesArgs(
        encryptionPreferences = encryptionPreferences,
        managementResourcePreferences = managementResourcePreferences,
        notificationPreferences = notificationPreferences,
        transportPreferences = transportPreferences,
    )
}
